<?php
/**
 * @file
 * XML parser for Rijksvideoserver files.
 */

/**
 * XML parser for Rijksvideoserver files.
 */
function _rijksvideo_parse_xml($url) {

  $xmlstr = file_get_contents($url);

  // Because Rijksvideo uses colons in the attribute names, we need to remove
  // this. So change overheidsVideo:foto to overheidsVideofoto.
  $xmlstr = preg_replace("/(<\/?)(\w+):([^>]*>)/", "$1$2$3", $xmlstr);

  $result = new SimpleXMLElement($xmlstr);
  foreach ($result->children() as $chapter) {
    foreach ($chapter->children() as $child) {
      $rijksvideo['thumbnail'] = isset($child->overheidsVideofoto) ? trim($child->overheidsVideofoto) : NULL;
      $rijksvideo['caption'] = isset($child->overheidsVideocaption) ? trim($child->overheidsVideocaption) : NULL;
      $rijksvideo['audio'] = isset($child->overheidsVideoaudio) ? trim($child->overheidsVideoaudio) : NULL;
      $rijksvideo['duration'] = isset($child->overheidsVideoduration) ? trim($child->overheidsVideoduration) : NULL;
      $rijksvideo['resolution'] = isset($child->overheidsVideoresolution) ? trim($child->overheidsVideoresolution) : NULL;
      $rijksvideo['language'] = isset($child->overheidsVideolanguage) ? trim($child->overheidsVideolanguage) : NULL;
      $rijksvideo['date'] = isset($child->pubDate) ? trim($child->pubDate) : NULL;
      $rijksvideo['transcription'] = isset($child->overheidsVideotranscript) ? trim($child->overheidsVideotranscript) : NULL;

      // If the result has a transcription, fetch it.
      if (!empty($rijksvideo['transcription'])) {
        $transcription = file_get_contents(trim($rijksvideo['transcription']));
        if (empty($transcription) || $transcription == 0) {
          $transcription = '';
        }
        $rijksvideo['transcription'] = $transcription;
      }

      foreach ($child->overheidsVideovideo as $video) {
        $video = (array) $video;
        $rijksvideo['videos'][$video['@attributes']['type']] = $video['@attributes'];
        $rijksvideo['videos'][$video['@attributes']['type']]['size'] = parse_size($video['@attributes']['size']);
        $rijksvideo['videos'][$video['@attributes']['type']]['url'] = $video[0];
      }
    }
  }

  return $rijksvideo;
}
